developerscripttools.DirectoryScript
====================================

.. inheritance-diagram:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.alias

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.long_description

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.scripting_group

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.short_description

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

Methods
-------

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.process_args

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.setup_argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
